# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import nifgen_pb2 as nifgen__pb2


class NiFgenStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Init = channel.unary_unary(
                '/nifgen_grpc.NiFgen/Init',
                request_serializer=nifgen__pb2.InitRequest.SerializeToString,
                response_deserializer=nifgen__pb2.InitResponse.FromString,
                )
        self.InitWithOptions = channel.unary_unary(
                '/nifgen_grpc.NiFgen/InitWithOptions',
                request_serializer=nifgen__pb2.InitWithOptionsRequest.SerializeToString,
                response_deserializer=nifgen__pb2.InitWithOptionsResponse.FromString,
                )
        self.InitializeWithChannels = channel.unary_unary(
                '/nifgen_grpc.NiFgen/InitializeWithChannels',
                request_serializer=nifgen__pb2.InitializeWithChannelsRequest.SerializeToString,
                response_deserializer=nifgen__pb2.InitializeWithChannelsResponse.FromString,
                )
        self.Close = channel.unary_unary(
                '/nifgen_grpc.NiFgen/Close',
                request_serializer=nifgen__pb2.CloseRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CloseResponse.FromString,
                )
        self.Reset = channel.unary_unary(
                '/nifgen_grpc.NiFgen/Reset',
                request_serializer=nifgen__pb2.ResetRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ResetResponse.FromString,
                )
        self.SelfTest = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SelfTest',
                request_serializer=nifgen__pb2.SelfTestRequest.SerializeToString,
                response_deserializer=nifgen__pb2.SelfTestResponse.FromString,
                )
        self.ErrorQuery = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ErrorQuery',
                request_serializer=nifgen__pb2.ErrorQueryRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ErrorQueryResponse.FromString,
                )
        self.ErrorMessage = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ErrorMessage',
                request_serializer=nifgen__pb2.ErrorMessageRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ErrorMessageResponse.FromString,
                )
        self.RevisionQuery = channel.unary_unary(
                '/nifgen_grpc.NiFgen/RevisionQuery',
                request_serializer=nifgen__pb2.RevisionQueryRequest.SerializeToString,
                response_deserializer=nifgen__pb2.RevisionQueryResponse.FromString,
                )
        self.GetError = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetError',
                request_serializer=nifgen__pb2.GetErrorRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetErrorResponse.FromString,
                )
        self.ClearError = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ClearError',
                request_serializer=nifgen__pb2.ClearErrorRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ClearErrorResponse.FromString,
                )
        self.ErrorHandler = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ErrorHandler',
                request_serializer=nifgen__pb2.ErrorHandlerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ErrorHandlerResponse.FromString,
                )
        self.GetChannelName = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetChannelName',
                request_serializer=nifgen__pb2.GetChannelNameRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetChannelNameResponse.FromString,
                )
        self.ResetInterchangeCheck = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ResetInterchangeCheck',
                request_serializer=nifgen__pb2.ResetInterchangeCheckRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ResetInterchangeCheckResponse.FromString,
                )
        self.ClearInterchangeWarnings = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ClearInterchangeWarnings',
                request_serializer=nifgen__pb2.ClearInterchangeWarningsRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ClearInterchangeWarningsResponse.FromString,
                )
        self.InvalidateAllAttributes = channel.unary_unary(
                '/nifgen_grpc.NiFgen/InvalidateAllAttributes',
                request_serializer=nifgen__pb2.InvalidateAllAttributesRequest.SerializeToString,
                response_deserializer=nifgen__pb2.InvalidateAllAttributesResponse.FromString,
                )
        self.ResetWithDefaults = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ResetWithDefaults',
                request_serializer=nifgen__pb2.ResetWithDefaultsRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ResetWithDefaultsResponse.FromString,
                )
        self.Disable = channel.unary_unary(
                '/nifgen_grpc.NiFgen/Disable',
                request_serializer=nifgen__pb2.DisableRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DisableResponse.FromString,
                )
        self.Commit = channel.unary_unary(
                '/nifgen_grpc.NiFgen/Commit',
                request_serializer=nifgen__pb2.CommitRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CommitResponse.FromString,
                )
        self.GetHardwareState = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetHardwareState',
                request_serializer=nifgen__pb2.GetHardwareStateRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetHardwareStateResponse.FromString,
                )
        self.WaitUntilDone = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WaitUntilDone',
                request_serializer=nifgen__pb2.WaitUntilDoneRequest.SerializeToString,
                response_deserializer=nifgen__pb2.WaitUntilDoneResponse.FromString,
                )
        self.IsDone = channel.unary_unary(
                '/nifgen_grpc.NiFgen/IsDone',
                request_serializer=nifgen__pb2.IsDoneRequest.SerializeToString,
                response_deserializer=nifgen__pb2.IsDoneResponse.FromString,
                )
        self.ResetDevice = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ResetDevice',
                request_serializer=nifgen__pb2.ResetDeviceRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ResetDeviceResponse.FromString,
                )
        self.ConfigureOperationMode = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureOperationMode',
                request_serializer=nifgen__pb2.ConfigureOperationModeRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureOperationModeResponse.FromString,
                )
        self.ConfigureOutputMode = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureOutputMode',
                request_serializer=nifgen__pb2.ConfigureOutputModeRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureOutputModeResponse.FromString,
                )
        self.ConfigureReferenceClock = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureReferenceClock',
                request_serializer=nifgen__pb2.ConfigureReferenceClockRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureReferenceClockResponse.FromString,
                )
        self.ConfigureOutputImpedance = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureOutputImpedance',
                request_serializer=nifgen__pb2.ConfigureOutputImpedanceRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureOutputImpedanceResponse.FromString,
                )
        self.ConfigureOutputEnabled = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureOutputEnabled',
                request_serializer=nifgen__pb2.ConfigureOutputEnabledRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureOutputEnabledResponse.FromString,
                )
        self.ConfigureChannels = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureChannels',
                request_serializer=nifgen__pb2.ConfigureChannelsRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureChannelsResponse.FromString,
                )
        self.InitiateGeneration = channel.unary_unary(
                '/nifgen_grpc.NiFgen/InitiateGeneration',
                request_serializer=nifgen__pb2.InitiateGenerationRequest.SerializeToString,
                response_deserializer=nifgen__pb2.InitiateGenerationResponse.FromString,
                )
        self.AbortGeneration = channel.unary_unary(
                '/nifgen_grpc.NiFgen/AbortGeneration',
                request_serializer=nifgen__pb2.AbortGenerationRequest.SerializeToString,
                response_deserializer=nifgen__pb2.AbortGenerationResponse.FromString,
                )
        self.ConfigureStandardWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureStandardWaveform',
                request_serializer=nifgen__pb2.ConfigureStandardWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureStandardWaveformResponse.FromString,
                )
        self.DefineUserStandardWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/DefineUserStandardWaveform',
                request_serializer=nifgen__pb2.DefineUserStandardWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DefineUserStandardWaveformResponse.FromString,
                )
        self.ClearUserStandardWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ClearUserStandardWaveform',
                request_serializer=nifgen__pb2.ClearUserStandardWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ClearUserStandardWaveformResponse.FromString,
                )
        self.ConfigureFrequency = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureFrequency',
                request_serializer=nifgen__pb2.ConfigureFrequencyRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureFrequencyResponse.FromString,
                )
        self.ConfigureAmplitude = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureAmplitude',
                request_serializer=nifgen__pb2.ConfigureAmplitudeRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureAmplitudeResponse.FromString,
                )
        self.QueryArbWfmCapabilities = channel.unary_unary(
                '/nifgen_grpc.NiFgen/QueryArbWfmCapabilities',
                request_serializer=nifgen__pb2.QueryArbWfmCapabilitiesRequest.SerializeToString,
                response_deserializer=nifgen__pb2.QueryArbWfmCapabilitiesResponse.FromString,
                )
        self.CreateWaveformF64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateWaveformF64',
                request_serializer=nifgen__pb2.CreateWaveformF64Request.SerializeToString,
                response_deserializer=nifgen__pb2.CreateWaveformF64Response.FromString,
                )
        self.CreateWaveformI16 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateWaveformI16',
                request_serializer=nifgen__pb2.CreateWaveformI16Request.SerializeToString,
                response_deserializer=nifgen__pb2.CreateWaveformI16Response.FromString,
                )
        self.CreateWaveformComplexF64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateWaveformComplexF64',
                request_serializer=nifgen__pb2.CreateWaveformComplexF64Request.SerializeToString,
                response_deserializer=nifgen__pb2.CreateWaveformComplexF64Response.FromString,
                )
        self.CreateWaveformFromFileI16 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateWaveformFromFileI16',
                request_serializer=nifgen__pb2.CreateWaveformFromFileI16Request.SerializeToString,
                response_deserializer=nifgen__pb2.CreateWaveformFromFileI16Response.FromString,
                )
        self.CreateWaveformFromFileF64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateWaveformFromFileF64',
                request_serializer=nifgen__pb2.CreateWaveformFromFileF64Request.SerializeToString,
                response_deserializer=nifgen__pb2.CreateWaveformFromFileF64Response.FromString,
                )
        self.ConfigureSampleRate = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureSampleRate',
                request_serializer=nifgen__pb2.ConfigureSampleRateRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureSampleRateResponse.FromString,
                )
        self.ConfigureArbWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureArbWaveform',
                request_serializer=nifgen__pb2.ConfigureArbWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureArbWaveformResponse.FromString,
                )
        self.ClearArbWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ClearArbWaveform',
                request_serializer=nifgen__pb2.ClearArbWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ClearArbWaveformResponse.FromString,
                )
        self.AllocateNamedWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/AllocateNamedWaveform',
                request_serializer=nifgen__pb2.AllocateNamedWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.AllocateNamedWaveformResponse.FromString,
                )
        self.SetNamedWaveformNextWritePosition = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SetNamedWaveformNextWritePosition',
                request_serializer=nifgen__pb2.SetNamedWaveformNextWritePositionRequest.SerializeToString,
                response_deserializer=nifgen__pb2.SetNamedWaveformNextWritePositionResponse.FromString,
                )
        self.WriteNamedWaveformF64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteNamedWaveformF64',
                request_serializer=nifgen__pb2.WriteNamedWaveformF64Request.SerializeToString,
                response_deserializer=nifgen__pb2.WriteNamedWaveformF64Response.FromString,
                )
        self.WriteNamedWaveformI16 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteNamedWaveformI16',
                request_serializer=nifgen__pb2.WriteNamedWaveformI16Request.SerializeToString,
                response_deserializer=nifgen__pb2.WriteNamedWaveformI16Response.FromString,
                )
        self.WriteNamedWaveformComplexF64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteNamedWaveformComplexF64',
                request_serializer=nifgen__pb2.WriteNamedWaveformComplexF64Request.SerializeToString,
                response_deserializer=nifgen__pb2.WriteNamedWaveformComplexF64Response.FromString,
                )
        self.WriteNamedWaveformComplexI16 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteNamedWaveformComplexI16',
                request_serializer=nifgen__pb2.WriteNamedWaveformComplexI16Request.SerializeToString,
                response_deserializer=nifgen__pb2.WriteNamedWaveformComplexI16Response.FromString,
                )
        self.DeleteNamedWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/DeleteNamedWaveform',
                request_serializer=nifgen__pb2.DeleteNamedWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DeleteNamedWaveformResponse.FromString,
                )
        self.QueryArbSeqCapabilities = channel.unary_unary(
                '/nifgen_grpc.NiFgen/QueryArbSeqCapabilities',
                request_serializer=nifgen__pb2.QueryArbSeqCapabilitiesRequest.SerializeToString,
                response_deserializer=nifgen__pb2.QueryArbSeqCapabilitiesResponse.FromString,
                )
        self.CreateArbSequence = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateArbSequence',
                request_serializer=nifgen__pb2.CreateArbSequenceRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CreateArbSequenceResponse.FromString,
                )
        self.CreateAdvancedArbSequence = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateAdvancedArbSequence',
                request_serializer=nifgen__pb2.CreateAdvancedArbSequenceRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CreateAdvancedArbSequenceResponse.FromString,
                )
        self.ConfigureArbSequence = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureArbSequence',
                request_serializer=nifgen__pb2.ConfigureArbSequenceRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureArbSequenceResponse.FromString,
                )
        self.ClearArbSequence = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ClearArbSequence',
                request_serializer=nifgen__pb2.ClearArbSequenceRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ClearArbSequenceResponse.FromString,
                )
        self.ClearArbMemory = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ClearArbMemory',
                request_serializer=nifgen__pb2.ClearArbMemoryRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ClearArbMemoryResponse.FromString,
                )
        self.QueryFreqListCapabilities = channel.unary_unary(
                '/nifgen_grpc.NiFgen/QueryFreqListCapabilities',
                request_serializer=nifgen__pb2.QueryFreqListCapabilitiesRequest.SerializeToString,
                response_deserializer=nifgen__pb2.QueryFreqListCapabilitiesResponse.FromString,
                )
        self.CreateFreqList = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateFreqList',
                request_serializer=nifgen__pb2.CreateFreqListRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CreateFreqListResponse.FromString,
                )
        self.ConfigureFreqList = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureFreqList',
                request_serializer=nifgen__pb2.ConfigureFreqListRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureFreqListResponse.FromString,
                )
        self.ClearFreqList = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ClearFreqList',
                request_serializer=nifgen__pb2.ClearFreqListRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ClearFreqListResponse.FromString,
                )
        self.WriteScript = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteScript',
                request_serializer=nifgen__pb2.WriteScriptRequest.SerializeToString,
                response_deserializer=nifgen__pb2.WriteScriptResponse.FromString,
                )
        self.DeleteScript = channel.unary_unary(
                '/nifgen_grpc.NiFgen/DeleteScript',
                request_serializer=nifgen__pb2.DeleteScriptRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DeleteScriptResponse.FromString,
                )
        self.ExportSignal = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ExportSignal',
                request_serializer=nifgen__pb2.ExportSignalRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ExportSignalResponse.FromString,
                )
        self.RouteSignalOut = channel.unary_unary(
                '/nifgen_grpc.NiFgen/RouteSignalOut',
                request_serializer=nifgen__pb2.RouteSignalOutRequest.SerializeToString,
                response_deserializer=nifgen__pb2.RouteSignalOutResponse.FromString,
                )
        self.SendSoftwareEdgeTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SendSoftwareEdgeTrigger',
                request_serializer=nifgen__pb2.SendSoftwareEdgeTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.SendSoftwareEdgeTriggerResponse.FromString,
                )
        self.ConfigureDigitalEdgeStartTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureDigitalEdgeStartTrigger',
                request_serializer=nifgen__pb2.ConfigureDigitalEdgeStartTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureDigitalEdgeStartTriggerResponse.FromString,
                )
        self.ConfigureSoftwareEdgeStartTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureSoftwareEdgeStartTrigger',
                request_serializer=nifgen__pb2.ConfigureSoftwareEdgeStartTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureSoftwareEdgeStartTriggerResponse.FromString,
                )
        self.DisableStartTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/DisableStartTrigger',
                request_serializer=nifgen__pb2.DisableStartTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DisableStartTriggerResponse.FromString,
                )
        self.ConfigureP2PEndpointFullnessStartTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureP2PEndpointFullnessStartTrigger',
                request_serializer=nifgen__pb2.ConfigureP2PEndpointFullnessStartTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureP2PEndpointFullnessStartTriggerResponse.FromString,
                )
        self.ConfigureDigitalEdgeScriptTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureDigitalEdgeScriptTrigger',
                request_serializer=nifgen__pb2.ConfigureDigitalEdgeScriptTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureDigitalEdgeScriptTriggerResponse.FromString,
                )
        self.ConfigureDigitalLevelScriptTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureDigitalLevelScriptTrigger',
                request_serializer=nifgen__pb2.ConfigureDigitalLevelScriptTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureDigitalLevelScriptTriggerResponse.FromString,
                )
        self.ConfigureSoftwareEdgeScriptTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureSoftwareEdgeScriptTrigger',
                request_serializer=nifgen__pb2.ConfigureSoftwareEdgeScriptTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureSoftwareEdgeScriptTriggerResponse.FromString,
                )
        self.DisableScriptTrigger = channel.unary_unary(
                '/nifgen_grpc.NiFgen/DisableScriptTrigger',
                request_serializer=nifgen__pb2.DisableScriptTriggerRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DisableScriptTriggerResponse.FromString,
                )
        self.ConfigureClockMode = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureClockMode',
                request_serializer=nifgen__pb2.ConfigureClockModeRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureClockModeResponse.FromString,
                )
        self.AdjustSampleClockRelativeDelay = channel.unary_unary(
                '/nifgen_grpc.NiFgen/AdjustSampleClockRelativeDelay',
                request_serializer=nifgen__pb2.AdjustSampleClockRelativeDelayRequest.SerializeToString,
                response_deserializer=nifgen__pb2.AdjustSampleClockRelativeDelayResponse.FromString,
                )
        self.AllocateWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/AllocateWaveform',
                request_serializer=nifgen__pb2.AllocateWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.AllocateWaveformResponse.FromString,
                )
        self.SetWaveformNextWritePosition = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SetWaveformNextWritePosition',
                request_serializer=nifgen__pb2.SetWaveformNextWritePositionRequest.SerializeToString,
                response_deserializer=nifgen__pb2.SetWaveformNextWritePositionResponse.FromString,
                )
        self.WriteWaveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteWaveform',
                request_serializer=nifgen__pb2.WriteWaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.WriteWaveformResponse.FromString,
                )
        self.WriteBinary16Waveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteBinary16Waveform',
                request_serializer=nifgen__pb2.WriteBinary16WaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.WriteBinary16WaveformResponse.FromString,
                )
        self.WriteWaveformComplexF64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteWaveformComplexF64',
                request_serializer=nifgen__pb2.WriteWaveformComplexF64Request.SerializeToString,
                response_deserializer=nifgen__pb2.WriteWaveformComplexF64Response.FromString,
                )
        self.WriteComplexBinary16Waveform = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteComplexBinary16Waveform',
                request_serializer=nifgen__pb2.WriteComplexBinary16WaveformRequest.SerializeToString,
                response_deserializer=nifgen__pb2.WriteComplexBinary16WaveformResponse.FromString,
                )
        self.SelfCal = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SelfCal',
                request_serializer=nifgen__pb2.SelfCalRequest.SerializeToString,
                response_deserializer=nifgen__pb2.SelfCalResponse.FromString,
                )
        self.GetSelfCalSupported = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetSelfCalSupported',
                request_serializer=nifgen__pb2.GetSelfCalSupportedRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetSelfCalSupportedResponse.FromString,
                )
        self.GetSelfCalLastDateAndTime = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetSelfCalLastDateAndTime',
                request_serializer=nifgen__pb2.GetSelfCalLastDateAndTimeRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetSelfCalLastDateAndTimeResponse.FromString,
                )
        self.GetExtCalLastDateAndTime = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetExtCalLastDateAndTime',
                request_serializer=nifgen__pb2.GetExtCalLastDateAndTimeRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetExtCalLastDateAndTimeResponse.FromString,
                )
        self.GetSelfCalLastTemp = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetSelfCalLastTemp',
                request_serializer=nifgen__pb2.GetSelfCalLastTempRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetSelfCalLastTempResponse.FromString,
                )
        self.GetExtCalLastTemp = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetExtCalLastTemp',
                request_serializer=nifgen__pb2.GetExtCalLastTempRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetExtCalLastTempResponse.FromString,
                )
        self.GetExtCalRecommendedInterval = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetExtCalRecommendedInterval',
                request_serializer=nifgen__pb2.GetExtCalRecommendedIntervalRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetExtCalRecommendedIntervalResponse.FromString,
                )
        self.ReadCurrentTemperature = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ReadCurrentTemperature',
                request_serializer=nifgen__pb2.ReadCurrentTemperatureRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ReadCurrentTemperatureResponse.FromString,
                )
        self.ConfigureCustomFIRFilterCoefficients = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureCustomFIRFilterCoefficients',
                request_serializer=nifgen__pb2.ConfigureCustomFIRFilterCoefficientsRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureCustomFIRFilterCoefficientsResponse.FromString,
                )
        self.GetFIRFilterCoefficients = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetFIRFilterCoefficients',
                request_serializer=nifgen__pb2.GetFIRFilterCoefficientsRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetFIRFilterCoefficientsResponse.FromString,
                )
        self.GetStreamEndpointHandle = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetStreamEndpointHandle',
                request_serializer=nifgen__pb2.GetStreamEndpointHandleRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetStreamEndpointHandleResponse.FromString,
                )
        self.WriteP2PEndpointI16 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/WriteP2PEndpointI16',
                request_serializer=nifgen__pb2.WriteP2PEndpointI16Request.SerializeToString,
                response_deserializer=nifgen__pb2.WriteP2PEndpointI16Response.FromString,
                )
        self.ConfigureSynchronization = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureSynchronization',
                request_serializer=nifgen__pb2.ConfigureSynchronizationRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureSynchronizationResponse.FromString,
                )
        self.EnableDigitalPatterning = channel.unary_unary(
                '/nifgen_grpc.NiFgen/EnableDigitalPatterning',
                request_serializer=nifgen__pb2.EnableDigitalPatterningRequest.SerializeToString,
                response_deserializer=nifgen__pb2.EnableDigitalPatterningResponse.FromString,
                )
        self.DisableDigitalPatterning = channel.unary_unary(
                '/nifgen_grpc.NiFgen/DisableDigitalPatterning',
                request_serializer=nifgen__pb2.DisableDigitalPatterningRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DisableDigitalPatterningResponse.FromString,
                )
        self.EnableDigitalFilter = channel.unary_unary(
                '/nifgen_grpc.NiFgen/EnableDigitalFilter',
                request_serializer=nifgen__pb2.EnableDigitalFilterRequest.SerializeToString,
                response_deserializer=nifgen__pb2.EnableDigitalFilterResponse.FromString,
                )
        self.DisableDigitalFilter = channel.unary_unary(
                '/nifgen_grpc.NiFgen/DisableDigitalFilter',
                request_serializer=nifgen__pb2.DisableDigitalFilterRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DisableDigitalFilterResponse.FromString,
                )
        self.EnableAnalogFilter = channel.unary_unary(
                '/nifgen_grpc.NiFgen/EnableAnalogFilter',
                request_serializer=nifgen__pb2.EnableAnalogFilterRequest.SerializeToString,
                response_deserializer=nifgen__pb2.EnableAnalogFilterResponse.FromString,
                )
        self.DisableAnalogFilter = channel.unary_unary(
                '/nifgen_grpc.NiFgen/DisableAnalogFilter',
                request_serializer=nifgen__pb2.DisableAnalogFilterRequest.SerializeToString,
                response_deserializer=nifgen__pb2.DisableAnalogFilterResponse.FromString,
                )
        self.ConfigureSampleClockSource = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureSampleClockSource',
                request_serializer=nifgen__pb2.ConfigureSampleClockSourceRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureSampleClockSourceResponse.FromString,
                )
        self.ConfigureTriggerMode = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ConfigureTriggerMode',
                request_serializer=nifgen__pb2.ConfigureTriggerModeRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ConfigureTriggerModeResponse.FromString,
                )
        self.ImportAttributeConfigurationFile = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ImportAttributeConfigurationFile',
                request_serializer=nifgen__pb2.ImportAttributeConfigurationFileRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ImportAttributeConfigurationFileResponse.FromString,
                )
        self.ExportAttributeConfigurationFile = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ExportAttributeConfigurationFile',
                request_serializer=nifgen__pb2.ExportAttributeConfigurationFileRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ExportAttributeConfigurationFileResponse.FromString,
                )
        self.ImportAttributeConfigurationBuffer = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ImportAttributeConfigurationBuffer',
                request_serializer=nifgen__pb2.ImportAttributeConfigurationBufferRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ImportAttributeConfigurationBufferResponse.FromString,
                )
        self.ExportAttributeConfigurationBuffer = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ExportAttributeConfigurationBuffer',
                request_serializer=nifgen__pb2.ExportAttributeConfigurationBufferRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ExportAttributeConfigurationBufferResponse.FromString,
                )
        self.SetAttributeViInt64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SetAttributeViInt64',
                request_serializer=nifgen__pb2.SetAttributeViInt64Request.SerializeToString,
                response_deserializer=nifgen__pb2.SetAttributeViInt64Response.FromString,
                )
        self.CheckAttributeViInt64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CheckAttributeViInt64',
                request_serializer=nifgen__pb2.CheckAttributeViInt64Request.SerializeToString,
                response_deserializer=nifgen__pb2.CheckAttributeViInt64Response.FromString,
                )
        self.GetAttributeViInt64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetAttributeViInt64',
                request_serializer=nifgen__pb2.GetAttributeViInt64Request.SerializeToString,
                response_deserializer=nifgen__pb2.GetAttributeViInt64Response.FromString,
                )
        self.SetAttributeViInt32 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SetAttributeViInt32',
                request_serializer=nifgen__pb2.SetAttributeViInt32Request.SerializeToString,
                response_deserializer=nifgen__pb2.SetAttributeViInt32Response.FromString,
                )
        self.SetAttributeViReal64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SetAttributeViReal64',
                request_serializer=nifgen__pb2.SetAttributeViReal64Request.SerializeToString,
                response_deserializer=nifgen__pb2.SetAttributeViReal64Response.FromString,
                )
        self.SetAttributeViString = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SetAttributeViString',
                request_serializer=nifgen__pb2.SetAttributeViStringRequest.SerializeToString,
                response_deserializer=nifgen__pb2.SetAttributeViStringResponse.FromString,
                )
        self.SetAttributeViBoolean = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SetAttributeViBoolean',
                request_serializer=nifgen__pb2.SetAttributeViBooleanRequest.SerializeToString,
                response_deserializer=nifgen__pb2.SetAttributeViBooleanResponse.FromString,
                )
        self.SetAttributeViSession = channel.unary_unary(
                '/nifgen_grpc.NiFgen/SetAttributeViSession',
                request_serializer=nifgen__pb2.SetAttributeViSessionRequest.SerializeToString,
                response_deserializer=nifgen__pb2.SetAttributeViSessionResponse.FromString,
                )
        self.CheckAttributeViInt32 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CheckAttributeViInt32',
                request_serializer=nifgen__pb2.CheckAttributeViInt32Request.SerializeToString,
                response_deserializer=nifgen__pb2.CheckAttributeViInt32Response.FromString,
                )
        self.CheckAttributeViReal64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CheckAttributeViReal64',
                request_serializer=nifgen__pb2.CheckAttributeViReal64Request.SerializeToString,
                response_deserializer=nifgen__pb2.CheckAttributeViReal64Response.FromString,
                )
        self.CheckAttributeViString = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CheckAttributeViString',
                request_serializer=nifgen__pb2.CheckAttributeViStringRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CheckAttributeViStringResponse.FromString,
                )
        self.CheckAttributeViBoolean = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CheckAttributeViBoolean',
                request_serializer=nifgen__pb2.CheckAttributeViBooleanRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CheckAttributeViBooleanResponse.FromString,
                )
        self.CheckAttributeViSession = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CheckAttributeViSession',
                request_serializer=nifgen__pb2.CheckAttributeViSessionRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CheckAttributeViSessionResponse.FromString,
                )
        self.GetAttributeViInt32 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetAttributeViInt32',
                request_serializer=nifgen__pb2.GetAttributeViInt32Request.SerializeToString,
                response_deserializer=nifgen__pb2.GetAttributeViInt32Response.FromString,
                )
        self.GetAttributeViReal64 = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetAttributeViReal64',
                request_serializer=nifgen__pb2.GetAttributeViReal64Request.SerializeToString,
                response_deserializer=nifgen__pb2.GetAttributeViReal64Response.FromString,
                )
        self.GetAttributeViString = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetAttributeViString',
                request_serializer=nifgen__pb2.GetAttributeViStringRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetAttributeViStringResponse.FromString,
                )
        self.GetAttributeViBoolean = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetAttributeViBoolean',
                request_serializer=nifgen__pb2.GetAttributeViBooleanRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetAttributeViBooleanResponse.FromString,
                )
        self.GetAttributeViSession = channel.unary_unary(
                '/nifgen_grpc.NiFgen/GetAttributeViSession',
                request_serializer=nifgen__pb2.GetAttributeViSessionRequest.SerializeToString,
                response_deserializer=nifgen__pb2.GetAttributeViSessionResponse.FromString,
                )
        self.ResetAttribute = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ResetAttribute',
                request_serializer=nifgen__pb2.ResetAttributeRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ResetAttributeResponse.FromString,
                )
        self.ManualEnableP2PStream = channel.unary_unary(
                '/nifgen_grpc.NiFgen/ManualEnableP2PStream',
                request_serializer=nifgen__pb2.ManualEnableP2PStreamRequest.SerializeToString,
                response_deserializer=nifgen__pb2.ManualEnableP2PStreamResponse.FromString,
                )
        self.CreateWaveformFromFileHWS = channel.unary_unary(
                '/nifgen_grpc.NiFgen/CreateWaveformFromFileHWS',
                request_serializer=nifgen__pb2.CreateWaveformFromFileHWSRequest.SerializeToString,
                response_deserializer=nifgen__pb2.CreateWaveformFromFileHWSResponse.FromString,
                )


class NiFgenServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Init(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitWithOptions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitializeWithChannels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Close(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SelfTest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ErrorQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ErrorMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevisionQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetError(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearError(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ErrorHandler(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChannelName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetInterchangeCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearInterchangeWarnings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvalidateAllAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetWithDefaults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Disable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Commit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHardwareState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WaitUntilDone(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsDone(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureOperationMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureOutputMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureReferenceClock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureOutputImpedance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureOutputEnabled(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureChannels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitiateGeneration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortGeneration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureStandardWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DefineUserStandardWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearUserStandardWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureFrequency(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureAmplitude(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryArbWfmCapabilities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWaveformF64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWaveformI16(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWaveformComplexF64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWaveformFromFileI16(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWaveformFromFileF64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureSampleRate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureArbWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearArbWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllocateNamedWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNamedWaveformNextWritePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteNamedWaveformF64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteNamedWaveformI16(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteNamedWaveformComplexF64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteNamedWaveformComplexI16(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNamedWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryArbSeqCapabilities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateArbSequence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAdvancedArbSequence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureArbSequence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearArbSequence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearArbMemory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryFreqListCapabilities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFreqList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureFreqList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearFreqList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteScript(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteScript(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportSignal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RouteSignalOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendSoftwareEdgeTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureDigitalEdgeStartTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureSoftwareEdgeStartTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableStartTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureP2PEndpointFullnessStartTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureDigitalEdgeScriptTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureDigitalLevelScriptTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureSoftwareEdgeScriptTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableScriptTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureClockMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdjustSampleClockRelativeDelay(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllocateWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetWaveformNextWritePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteBinary16Waveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteWaveformComplexF64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteComplexBinary16Waveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SelfCal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelfCalSupported(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelfCalLastDateAndTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtCalLastDateAndTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelfCalLastTemp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtCalLastTemp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtCalRecommendedInterval(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadCurrentTemperature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureCustomFIRFilterCoefficients(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFIRFilterCoefficients(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStreamEndpointHandle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteP2PEndpointI16(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureSynchronization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableDigitalPatterning(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableDigitalPatterning(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableDigitalFilter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableDigitalFilter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableAnalogFilter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableAnalogFilter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureSampleClockSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureTriggerMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportAttributeConfigurationFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportAttributeConfigurationFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportAttributeConfigurationBuffer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportAttributeConfigurationBuffer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViInt64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViInt64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViInt64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViInt32(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViReal64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViString(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViBoolean(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViInt32(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViReal64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViString(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViBoolean(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViInt32(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViReal64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViString(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViBoolean(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetAttribute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ManualEnableP2PStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWaveformFromFileHWS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NiFgenServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Init': grpc.unary_unary_rpc_method_handler(
                    servicer.Init,
                    request_deserializer=nifgen__pb2.InitRequest.FromString,
                    response_serializer=nifgen__pb2.InitResponse.SerializeToString,
            ),
            'InitWithOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.InitWithOptions,
                    request_deserializer=nifgen__pb2.InitWithOptionsRequest.FromString,
                    response_serializer=nifgen__pb2.InitWithOptionsResponse.SerializeToString,
            ),
            'InitializeWithChannels': grpc.unary_unary_rpc_method_handler(
                    servicer.InitializeWithChannels,
                    request_deserializer=nifgen__pb2.InitializeWithChannelsRequest.FromString,
                    response_serializer=nifgen__pb2.InitializeWithChannelsResponse.SerializeToString,
            ),
            'Close': grpc.unary_unary_rpc_method_handler(
                    servicer.Close,
                    request_deserializer=nifgen__pb2.CloseRequest.FromString,
                    response_serializer=nifgen__pb2.CloseResponse.SerializeToString,
            ),
            'Reset': grpc.unary_unary_rpc_method_handler(
                    servicer.Reset,
                    request_deserializer=nifgen__pb2.ResetRequest.FromString,
                    response_serializer=nifgen__pb2.ResetResponse.SerializeToString,
            ),
            'SelfTest': grpc.unary_unary_rpc_method_handler(
                    servicer.SelfTest,
                    request_deserializer=nifgen__pb2.SelfTestRequest.FromString,
                    response_serializer=nifgen__pb2.SelfTestResponse.SerializeToString,
            ),
            'ErrorQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.ErrorQuery,
                    request_deserializer=nifgen__pb2.ErrorQueryRequest.FromString,
                    response_serializer=nifgen__pb2.ErrorQueryResponse.SerializeToString,
            ),
            'ErrorMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.ErrorMessage,
                    request_deserializer=nifgen__pb2.ErrorMessageRequest.FromString,
                    response_serializer=nifgen__pb2.ErrorMessageResponse.SerializeToString,
            ),
            'RevisionQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.RevisionQuery,
                    request_deserializer=nifgen__pb2.RevisionQueryRequest.FromString,
                    response_serializer=nifgen__pb2.RevisionQueryResponse.SerializeToString,
            ),
            'GetError': grpc.unary_unary_rpc_method_handler(
                    servicer.GetError,
                    request_deserializer=nifgen__pb2.GetErrorRequest.FromString,
                    response_serializer=nifgen__pb2.GetErrorResponse.SerializeToString,
            ),
            'ClearError': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearError,
                    request_deserializer=nifgen__pb2.ClearErrorRequest.FromString,
                    response_serializer=nifgen__pb2.ClearErrorResponse.SerializeToString,
            ),
            'ErrorHandler': grpc.unary_unary_rpc_method_handler(
                    servicer.ErrorHandler,
                    request_deserializer=nifgen__pb2.ErrorHandlerRequest.FromString,
                    response_serializer=nifgen__pb2.ErrorHandlerResponse.SerializeToString,
            ),
            'GetChannelName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChannelName,
                    request_deserializer=nifgen__pb2.GetChannelNameRequest.FromString,
                    response_serializer=nifgen__pb2.GetChannelNameResponse.SerializeToString,
            ),
            'ResetInterchangeCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetInterchangeCheck,
                    request_deserializer=nifgen__pb2.ResetInterchangeCheckRequest.FromString,
                    response_serializer=nifgen__pb2.ResetInterchangeCheckResponse.SerializeToString,
            ),
            'ClearInterchangeWarnings': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearInterchangeWarnings,
                    request_deserializer=nifgen__pb2.ClearInterchangeWarningsRequest.FromString,
                    response_serializer=nifgen__pb2.ClearInterchangeWarningsResponse.SerializeToString,
            ),
            'InvalidateAllAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.InvalidateAllAttributes,
                    request_deserializer=nifgen__pb2.InvalidateAllAttributesRequest.FromString,
                    response_serializer=nifgen__pb2.InvalidateAllAttributesResponse.SerializeToString,
            ),
            'ResetWithDefaults': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetWithDefaults,
                    request_deserializer=nifgen__pb2.ResetWithDefaultsRequest.FromString,
                    response_serializer=nifgen__pb2.ResetWithDefaultsResponse.SerializeToString,
            ),
            'Disable': grpc.unary_unary_rpc_method_handler(
                    servicer.Disable,
                    request_deserializer=nifgen__pb2.DisableRequest.FromString,
                    response_serializer=nifgen__pb2.DisableResponse.SerializeToString,
            ),
            'Commit': grpc.unary_unary_rpc_method_handler(
                    servicer.Commit,
                    request_deserializer=nifgen__pb2.CommitRequest.FromString,
                    response_serializer=nifgen__pb2.CommitResponse.SerializeToString,
            ),
            'GetHardwareState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHardwareState,
                    request_deserializer=nifgen__pb2.GetHardwareStateRequest.FromString,
                    response_serializer=nifgen__pb2.GetHardwareStateResponse.SerializeToString,
            ),
            'WaitUntilDone': grpc.unary_unary_rpc_method_handler(
                    servicer.WaitUntilDone,
                    request_deserializer=nifgen__pb2.WaitUntilDoneRequest.FromString,
                    response_serializer=nifgen__pb2.WaitUntilDoneResponse.SerializeToString,
            ),
            'IsDone': grpc.unary_unary_rpc_method_handler(
                    servicer.IsDone,
                    request_deserializer=nifgen__pb2.IsDoneRequest.FromString,
                    response_serializer=nifgen__pb2.IsDoneResponse.SerializeToString,
            ),
            'ResetDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetDevice,
                    request_deserializer=nifgen__pb2.ResetDeviceRequest.FromString,
                    response_serializer=nifgen__pb2.ResetDeviceResponse.SerializeToString,
            ),
            'ConfigureOperationMode': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureOperationMode,
                    request_deserializer=nifgen__pb2.ConfigureOperationModeRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureOperationModeResponse.SerializeToString,
            ),
            'ConfigureOutputMode': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureOutputMode,
                    request_deserializer=nifgen__pb2.ConfigureOutputModeRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureOutputModeResponse.SerializeToString,
            ),
            'ConfigureReferenceClock': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureReferenceClock,
                    request_deserializer=nifgen__pb2.ConfigureReferenceClockRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureReferenceClockResponse.SerializeToString,
            ),
            'ConfigureOutputImpedance': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureOutputImpedance,
                    request_deserializer=nifgen__pb2.ConfigureOutputImpedanceRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureOutputImpedanceResponse.SerializeToString,
            ),
            'ConfigureOutputEnabled': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureOutputEnabled,
                    request_deserializer=nifgen__pb2.ConfigureOutputEnabledRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureOutputEnabledResponse.SerializeToString,
            ),
            'ConfigureChannels': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureChannels,
                    request_deserializer=nifgen__pb2.ConfigureChannelsRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureChannelsResponse.SerializeToString,
            ),
            'InitiateGeneration': grpc.unary_unary_rpc_method_handler(
                    servicer.InitiateGeneration,
                    request_deserializer=nifgen__pb2.InitiateGenerationRequest.FromString,
                    response_serializer=nifgen__pb2.InitiateGenerationResponse.SerializeToString,
            ),
            'AbortGeneration': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortGeneration,
                    request_deserializer=nifgen__pb2.AbortGenerationRequest.FromString,
                    response_serializer=nifgen__pb2.AbortGenerationResponse.SerializeToString,
            ),
            'ConfigureStandardWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureStandardWaveform,
                    request_deserializer=nifgen__pb2.ConfigureStandardWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureStandardWaveformResponse.SerializeToString,
            ),
            'DefineUserStandardWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.DefineUserStandardWaveform,
                    request_deserializer=nifgen__pb2.DefineUserStandardWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.DefineUserStandardWaveformResponse.SerializeToString,
            ),
            'ClearUserStandardWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearUserStandardWaveform,
                    request_deserializer=nifgen__pb2.ClearUserStandardWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.ClearUserStandardWaveformResponse.SerializeToString,
            ),
            'ConfigureFrequency': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureFrequency,
                    request_deserializer=nifgen__pb2.ConfigureFrequencyRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureFrequencyResponse.SerializeToString,
            ),
            'ConfigureAmplitude': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureAmplitude,
                    request_deserializer=nifgen__pb2.ConfigureAmplitudeRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureAmplitudeResponse.SerializeToString,
            ),
            'QueryArbWfmCapabilities': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryArbWfmCapabilities,
                    request_deserializer=nifgen__pb2.QueryArbWfmCapabilitiesRequest.FromString,
                    response_serializer=nifgen__pb2.QueryArbWfmCapabilitiesResponse.SerializeToString,
            ),
            'CreateWaveformF64': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWaveformF64,
                    request_deserializer=nifgen__pb2.CreateWaveformF64Request.FromString,
                    response_serializer=nifgen__pb2.CreateWaveformF64Response.SerializeToString,
            ),
            'CreateWaveformI16': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWaveformI16,
                    request_deserializer=nifgen__pb2.CreateWaveformI16Request.FromString,
                    response_serializer=nifgen__pb2.CreateWaveformI16Response.SerializeToString,
            ),
            'CreateWaveformComplexF64': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWaveformComplexF64,
                    request_deserializer=nifgen__pb2.CreateWaveformComplexF64Request.FromString,
                    response_serializer=nifgen__pb2.CreateWaveformComplexF64Response.SerializeToString,
            ),
            'CreateWaveformFromFileI16': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWaveformFromFileI16,
                    request_deserializer=nifgen__pb2.CreateWaveformFromFileI16Request.FromString,
                    response_serializer=nifgen__pb2.CreateWaveformFromFileI16Response.SerializeToString,
            ),
            'CreateWaveformFromFileF64': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWaveformFromFileF64,
                    request_deserializer=nifgen__pb2.CreateWaveformFromFileF64Request.FromString,
                    response_serializer=nifgen__pb2.CreateWaveformFromFileF64Response.SerializeToString,
            ),
            'ConfigureSampleRate': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureSampleRate,
                    request_deserializer=nifgen__pb2.ConfigureSampleRateRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureSampleRateResponse.SerializeToString,
            ),
            'ConfigureArbWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureArbWaveform,
                    request_deserializer=nifgen__pb2.ConfigureArbWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureArbWaveformResponse.SerializeToString,
            ),
            'ClearArbWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearArbWaveform,
                    request_deserializer=nifgen__pb2.ClearArbWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.ClearArbWaveformResponse.SerializeToString,
            ),
            'AllocateNamedWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.AllocateNamedWaveform,
                    request_deserializer=nifgen__pb2.AllocateNamedWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.AllocateNamedWaveformResponse.SerializeToString,
            ),
            'SetNamedWaveformNextWritePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNamedWaveformNextWritePosition,
                    request_deserializer=nifgen__pb2.SetNamedWaveformNextWritePositionRequest.FromString,
                    response_serializer=nifgen__pb2.SetNamedWaveformNextWritePositionResponse.SerializeToString,
            ),
            'WriteNamedWaveformF64': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteNamedWaveformF64,
                    request_deserializer=nifgen__pb2.WriteNamedWaveformF64Request.FromString,
                    response_serializer=nifgen__pb2.WriteNamedWaveformF64Response.SerializeToString,
            ),
            'WriteNamedWaveformI16': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteNamedWaveformI16,
                    request_deserializer=nifgen__pb2.WriteNamedWaveformI16Request.FromString,
                    response_serializer=nifgen__pb2.WriteNamedWaveformI16Response.SerializeToString,
            ),
            'WriteNamedWaveformComplexF64': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteNamedWaveformComplexF64,
                    request_deserializer=nifgen__pb2.WriteNamedWaveformComplexF64Request.FromString,
                    response_serializer=nifgen__pb2.WriteNamedWaveformComplexF64Response.SerializeToString,
            ),
            'WriteNamedWaveformComplexI16': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteNamedWaveformComplexI16,
                    request_deserializer=nifgen__pb2.WriteNamedWaveformComplexI16Request.FromString,
                    response_serializer=nifgen__pb2.WriteNamedWaveformComplexI16Response.SerializeToString,
            ),
            'DeleteNamedWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNamedWaveform,
                    request_deserializer=nifgen__pb2.DeleteNamedWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.DeleteNamedWaveformResponse.SerializeToString,
            ),
            'QueryArbSeqCapabilities': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryArbSeqCapabilities,
                    request_deserializer=nifgen__pb2.QueryArbSeqCapabilitiesRequest.FromString,
                    response_serializer=nifgen__pb2.QueryArbSeqCapabilitiesResponse.SerializeToString,
            ),
            'CreateArbSequence': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateArbSequence,
                    request_deserializer=nifgen__pb2.CreateArbSequenceRequest.FromString,
                    response_serializer=nifgen__pb2.CreateArbSequenceResponse.SerializeToString,
            ),
            'CreateAdvancedArbSequence': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAdvancedArbSequence,
                    request_deserializer=nifgen__pb2.CreateAdvancedArbSequenceRequest.FromString,
                    response_serializer=nifgen__pb2.CreateAdvancedArbSequenceResponse.SerializeToString,
            ),
            'ConfigureArbSequence': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureArbSequence,
                    request_deserializer=nifgen__pb2.ConfigureArbSequenceRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureArbSequenceResponse.SerializeToString,
            ),
            'ClearArbSequence': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearArbSequence,
                    request_deserializer=nifgen__pb2.ClearArbSequenceRequest.FromString,
                    response_serializer=nifgen__pb2.ClearArbSequenceResponse.SerializeToString,
            ),
            'ClearArbMemory': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearArbMemory,
                    request_deserializer=nifgen__pb2.ClearArbMemoryRequest.FromString,
                    response_serializer=nifgen__pb2.ClearArbMemoryResponse.SerializeToString,
            ),
            'QueryFreqListCapabilities': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryFreqListCapabilities,
                    request_deserializer=nifgen__pb2.QueryFreqListCapabilitiesRequest.FromString,
                    response_serializer=nifgen__pb2.QueryFreqListCapabilitiesResponse.SerializeToString,
            ),
            'CreateFreqList': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFreqList,
                    request_deserializer=nifgen__pb2.CreateFreqListRequest.FromString,
                    response_serializer=nifgen__pb2.CreateFreqListResponse.SerializeToString,
            ),
            'ConfigureFreqList': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureFreqList,
                    request_deserializer=nifgen__pb2.ConfigureFreqListRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureFreqListResponse.SerializeToString,
            ),
            'ClearFreqList': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearFreqList,
                    request_deserializer=nifgen__pb2.ClearFreqListRequest.FromString,
                    response_serializer=nifgen__pb2.ClearFreqListResponse.SerializeToString,
            ),
            'WriteScript': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteScript,
                    request_deserializer=nifgen__pb2.WriteScriptRequest.FromString,
                    response_serializer=nifgen__pb2.WriteScriptResponse.SerializeToString,
            ),
            'DeleteScript': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteScript,
                    request_deserializer=nifgen__pb2.DeleteScriptRequest.FromString,
                    response_serializer=nifgen__pb2.DeleteScriptResponse.SerializeToString,
            ),
            'ExportSignal': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportSignal,
                    request_deserializer=nifgen__pb2.ExportSignalRequest.FromString,
                    response_serializer=nifgen__pb2.ExportSignalResponse.SerializeToString,
            ),
            'RouteSignalOut': grpc.unary_unary_rpc_method_handler(
                    servicer.RouteSignalOut,
                    request_deserializer=nifgen__pb2.RouteSignalOutRequest.FromString,
                    response_serializer=nifgen__pb2.RouteSignalOutResponse.SerializeToString,
            ),
            'SendSoftwareEdgeTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.SendSoftwareEdgeTrigger,
                    request_deserializer=nifgen__pb2.SendSoftwareEdgeTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.SendSoftwareEdgeTriggerResponse.SerializeToString,
            ),
            'ConfigureDigitalEdgeStartTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureDigitalEdgeStartTrigger,
                    request_deserializer=nifgen__pb2.ConfigureDigitalEdgeStartTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureDigitalEdgeStartTriggerResponse.SerializeToString,
            ),
            'ConfigureSoftwareEdgeStartTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureSoftwareEdgeStartTrigger,
                    request_deserializer=nifgen__pb2.ConfigureSoftwareEdgeStartTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureSoftwareEdgeStartTriggerResponse.SerializeToString,
            ),
            'DisableStartTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableStartTrigger,
                    request_deserializer=nifgen__pb2.DisableStartTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.DisableStartTriggerResponse.SerializeToString,
            ),
            'ConfigureP2PEndpointFullnessStartTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureP2PEndpointFullnessStartTrigger,
                    request_deserializer=nifgen__pb2.ConfigureP2PEndpointFullnessStartTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureP2PEndpointFullnessStartTriggerResponse.SerializeToString,
            ),
            'ConfigureDigitalEdgeScriptTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureDigitalEdgeScriptTrigger,
                    request_deserializer=nifgen__pb2.ConfigureDigitalEdgeScriptTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureDigitalEdgeScriptTriggerResponse.SerializeToString,
            ),
            'ConfigureDigitalLevelScriptTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureDigitalLevelScriptTrigger,
                    request_deserializer=nifgen__pb2.ConfigureDigitalLevelScriptTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureDigitalLevelScriptTriggerResponse.SerializeToString,
            ),
            'ConfigureSoftwareEdgeScriptTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureSoftwareEdgeScriptTrigger,
                    request_deserializer=nifgen__pb2.ConfigureSoftwareEdgeScriptTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureSoftwareEdgeScriptTriggerResponse.SerializeToString,
            ),
            'DisableScriptTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableScriptTrigger,
                    request_deserializer=nifgen__pb2.DisableScriptTriggerRequest.FromString,
                    response_serializer=nifgen__pb2.DisableScriptTriggerResponse.SerializeToString,
            ),
            'ConfigureClockMode': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureClockMode,
                    request_deserializer=nifgen__pb2.ConfigureClockModeRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureClockModeResponse.SerializeToString,
            ),
            'AdjustSampleClockRelativeDelay': grpc.unary_unary_rpc_method_handler(
                    servicer.AdjustSampleClockRelativeDelay,
                    request_deserializer=nifgen__pb2.AdjustSampleClockRelativeDelayRequest.FromString,
                    response_serializer=nifgen__pb2.AdjustSampleClockRelativeDelayResponse.SerializeToString,
            ),
            'AllocateWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.AllocateWaveform,
                    request_deserializer=nifgen__pb2.AllocateWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.AllocateWaveformResponse.SerializeToString,
            ),
            'SetWaveformNextWritePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.SetWaveformNextWritePosition,
                    request_deserializer=nifgen__pb2.SetWaveformNextWritePositionRequest.FromString,
                    response_serializer=nifgen__pb2.SetWaveformNextWritePositionResponse.SerializeToString,
            ),
            'WriteWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteWaveform,
                    request_deserializer=nifgen__pb2.WriteWaveformRequest.FromString,
                    response_serializer=nifgen__pb2.WriteWaveformResponse.SerializeToString,
            ),
            'WriteBinary16Waveform': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteBinary16Waveform,
                    request_deserializer=nifgen__pb2.WriteBinary16WaveformRequest.FromString,
                    response_serializer=nifgen__pb2.WriteBinary16WaveformResponse.SerializeToString,
            ),
            'WriteWaveformComplexF64': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteWaveformComplexF64,
                    request_deserializer=nifgen__pb2.WriteWaveformComplexF64Request.FromString,
                    response_serializer=nifgen__pb2.WriteWaveformComplexF64Response.SerializeToString,
            ),
            'WriteComplexBinary16Waveform': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteComplexBinary16Waveform,
                    request_deserializer=nifgen__pb2.WriteComplexBinary16WaveformRequest.FromString,
                    response_serializer=nifgen__pb2.WriteComplexBinary16WaveformResponse.SerializeToString,
            ),
            'SelfCal': grpc.unary_unary_rpc_method_handler(
                    servicer.SelfCal,
                    request_deserializer=nifgen__pb2.SelfCalRequest.FromString,
                    response_serializer=nifgen__pb2.SelfCalResponse.SerializeToString,
            ),
            'GetSelfCalSupported': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSelfCalSupported,
                    request_deserializer=nifgen__pb2.GetSelfCalSupportedRequest.FromString,
                    response_serializer=nifgen__pb2.GetSelfCalSupportedResponse.SerializeToString,
            ),
            'GetSelfCalLastDateAndTime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSelfCalLastDateAndTime,
                    request_deserializer=nifgen__pb2.GetSelfCalLastDateAndTimeRequest.FromString,
                    response_serializer=nifgen__pb2.GetSelfCalLastDateAndTimeResponse.SerializeToString,
            ),
            'GetExtCalLastDateAndTime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtCalLastDateAndTime,
                    request_deserializer=nifgen__pb2.GetExtCalLastDateAndTimeRequest.FromString,
                    response_serializer=nifgen__pb2.GetExtCalLastDateAndTimeResponse.SerializeToString,
            ),
            'GetSelfCalLastTemp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSelfCalLastTemp,
                    request_deserializer=nifgen__pb2.GetSelfCalLastTempRequest.FromString,
                    response_serializer=nifgen__pb2.GetSelfCalLastTempResponse.SerializeToString,
            ),
            'GetExtCalLastTemp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtCalLastTemp,
                    request_deserializer=nifgen__pb2.GetExtCalLastTempRequest.FromString,
                    response_serializer=nifgen__pb2.GetExtCalLastTempResponse.SerializeToString,
            ),
            'GetExtCalRecommendedInterval': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtCalRecommendedInterval,
                    request_deserializer=nifgen__pb2.GetExtCalRecommendedIntervalRequest.FromString,
                    response_serializer=nifgen__pb2.GetExtCalRecommendedIntervalResponse.SerializeToString,
            ),
            'ReadCurrentTemperature': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadCurrentTemperature,
                    request_deserializer=nifgen__pb2.ReadCurrentTemperatureRequest.FromString,
                    response_serializer=nifgen__pb2.ReadCurrentTemperatureResponse.SerializeToString,
            ),
            'ConfigureCustomFIRFilterCoefficients': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureCustomFIRFilterCoefficients,
                    request_deserializer=nifgen__pb2.ConfigureCustomFIRFilterCoefficientsRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureCustomFIRFilterCoefficientsResponse.SerializeToString,
            ),
            'GetFIRFilterCoefficients': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFIRFilterCoefficients,
                    request_deserializer=nifgen__pb2.GetFIRFilterCoefficientsRequest.FromString,
                    response_serializer=nifgen__pb2.GetFIRFilterCoefficientsResponse.SerializeToString,
            ),
            'GetStreamEndpointHandle': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStreamEndpointHandle,
                    request_deserializer=nifgen__pb2.GetStreamEndpointHandleRequest.FromString,
                    response_serializer=nifgen__pb2.GetStreamEndpointHandleResponse.SerializeToString,
            ),
            'WriteP2PEndpointI16': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteP2PEndpointI16,
                    request_deserializer=nifgen__pb2.WriteP2PEndpointI16Request.FromString,
                    response_serializer=nifgen__pb2.WriteP2PEndpointI16Response.SerializeToString,
            ),
            'ConfigureSynchronization': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureSynchronization,
                    request_deserializer=nifgen__pb2.ConfigureSynchronizationRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureSynchronizationResponse.SerializeToString,
            ),
            'EnableDigitalPatterning': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableDigitalPatterning,
                    request_deserializer=nifgen__pb2.EnableDigitalPatterningRequest.FromString,
                    response_serializer=nifgen__pb2.EnableDigitalPatterningResponse.SerializeToString,
            ),
            'DisableDigitalPatterning': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableDigitalPatterning,
                    request_deserializer=nifgen__pb2.DisableDigitalPatterningRequest.FromString,
                    response_serializer=nifgen__pb2.DisableDigitalPatterningResponse.SerializeToString,
            ),
            'EnableDigitalFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableDigitalFilter,
                    request_deserializer=nifgen__pb2.EnableDigitalFilterRequest.FromString,
                    response_serializer=nifgen__pb2.EnableDigitalFilterResponse.SerializeToString,
            ),
            'DisableDigitalFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableDigitalFilter,
                    request_deserializer=nifgen__pb2.DisableDigitalFilterRequest.FromString,
                    response_serializer=nifgen__pb2.DisableDigitalFilterResponse.SerializeToString,
            ),
            'EnableAnalogFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableAnalogFilter,
                    request_deserializer=nifgen__pb2.EnableAnalogFilterRequest.FromString,
                    response_serializer=nifgen__pb2.EnableAnalogFilterResponse.SerializeToString,
            ),
            'DisableAnalogFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableAnalogFilter,
                    request_deserializer=nifgen__pb2.DisableAnalogFilterRequest.FromString,
                    response_serializer=nifgen__pb2.DisableAnalogFilterResponse.SerializeToString,
            ),
            'ConfigureSampleClockSource': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureSampleClockSource,
                    request_deserializer=nifgen__pb2.ConfigureSampleClockSourceRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureSampleClockSourceResponse.SerializeToString,
            ),
            'ConfigureTriggerMode': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureTriggerMode,
                    request_deserializer=nifgen__pb2.ConfigureTriggerModeRequest.FromString,
                    response_serializer=nifgen__pb2.ConfigureTriggerModeResponse.SerializeToString,
            ),
            'ImportAttributeConfigurationFile': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportAttributeConfigurationFile,
                    request_deserializer=nifgen__pb2.ImportAttributeConfigurationFileRequest.FromString,
                    response_serializer=nifgen__pb2.ImportAttributeConfigurationFileResponse.SerializeToString,
            ),
            'ExportAttributeConfigurationFile': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportAttributeConfigurationFile,
                    request_deserializer=nifgen__pb2.ExportAttributeConfigurationFileRequest.FromString,
                    response_serializer=nifgen__pb2.ExportAttributeConfigurationFileResponse.SerializeToString,
            ),
            'ImportAttributeConfigurationBuffer': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportAttributeConfigurationBuffer,
                    request_deserializer=nifgen__pb2.ImportAttributeConfigurationBufferRequest.FromString,
                    response_serializer=nifgen__pb2.ImportAttributeConfigurationBufferResponse.SerializeToString,
            ),
            'ExportAttributeConfigurationBuffer': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportAttributeConfigurationBuffer,
                    request_deserializer=nifgen__pb2.ExportAttributeConfigurationBufferRequest.FromString,
                    response_serializer=nifgen__pb2.ExportAttributeConfigurationBufferResponse.SerializeToString,
            ),
            'SetAttributeViInt64': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViInt64,
                    request_deserializer=nifgen__pb2.SetAttributeViInt64Request.FromString,
                    response_serializer=nifgen__pb2.SetAttributeViInt64Response.SerializeToString,
            ),
            'CheckAttributeViInt64': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViInt64,
                    request_deserializer=nifgen__pb2.CheckAttributeViInt64Request.FromString,
                    response_serializer=nifgen__pb2.CheckAttributeViInt64Response.SerializeToString,
            ),
            'GetAttributeViInt64': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViInt64,
                    request_deserializer=nifgen__pb2.GetAttributeViInt64Request.FromString,
                    response_serializer=nifgen__pb2.GetAttributeViInt64Response.SerializeToString,
            ),
            'SetAttributeViInt32': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViInt32,
                    request_deserializer=nifgen__pb2.SetAttributeViInt32Request.FromString,
                    response_serializer=nifgen__pb2.SetAttributeViInt32Response.SerializeToString,
            ),
            'SetAttributeViReal64': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViReal64,
                    request_deserializer=nifgen__pb2.SetAttributeViReal64Request.FromString,
                    response_serializer=nifgen__pb2.SetAttributeViReal64Response.SerializeToString,
            ),
            'SetAttributeViString': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViString,
                    request_deserializer=nifgen__pb2.SetAttributeViStringRequest.FromString,
                    response_serializer=nifgen__pb2.SetAttributeViStringResponse.SerializeToString,
            ),
            'SetAttributeViBoolean': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViBoolean,
                    request_deserializer=nifgen__pb2.SetAttributeViBooleanRequest.FromString,
                    response_serializer=nifgen__pb2.SetAttributeViBooleanResponse.SerializeToString,
            ),
            'SetAttributeViSession': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViSession,
                    request_deserializer=nifgen__pb2.SetAttributeViSessionRequest.FromString,
                    response_serializer=nifgen__pb2.SetAttributeViSessionResponse.SerializeToString,
            ),
            'CheckAttributeViInt32': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViInt32,
                    request_deserializer=nifgen__pb2.CheckAttributeViInt32Request.FromString,
                    response_serializer=nifgen__pb2.CheckAttributeViInt32Response.SerializeToString,
            ),
            'CheckAttributeViReal64': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViReal64,
                    request_deserializer=nifgen__pb2.CheckAttributeViReal64Request.FromString,
                    response_serializer=nifgen__pb2.CheckAttributeViReal64Response.SerializeToString,
            ),
            'CheckAttributeViString': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViString,
                    request_deserializer=nifgen__pb2.CheckAttributeViStringRequest.FromString,
                    response_serializer=nifgen__pb2.CheckAttributeViStringResponse.SerializeToString,
            ),
            'CheckAttributeViBoolean': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViBoolean,
                    request_deserializer=nifgen__pb2.CheckAttributeViBooleanRequest.FromString,
                    response_serializer=nifgen__pb2.CheckAttributeViBooleanResponse.SerializeToString,
            ),
            'CheckAttributeViSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViSession,
                    request_deserializer=nifgen__pb2.CheckAttributeViSessionRequest.FromString,
                    response_serializer=nifgen__pb2.CheckAttributeViSessionResponse.SerializeToString,
            ),
            'GetAttributeViInt32': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViInt32,
                    request_deserializer=nifgen__pb2.GetAttributeViInt32Request.FromString,
                    response_serializer=nifgen__pb2.GetAttributeViInt32Response.SerializeToString,
            ),
            'GetAttributeViReal64': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViReal64,
                    request_deserializer=nifgen__pb2.GetAttributeViReal64Request.FromString,
                    response_serializer=nifgen__pb2.GetAttributeViReal64Response.SerializeToString,
            ),
            'GetAttributeViString': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViString,
                    request_deserializer=nifgen__pb2.GetAttributeViStringRequest.FromString,
                    response_serializer=nifgen__pb2.GetAttributeViStringResponse.SerializeToString,
            ),
            'GetAttributeViBoolean': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViBoolean,
                    request_deserializer=nifgen__pb2.GetAttributeViBooleanRequest.FromString,
                    response_serializer=nifgen__pb2.GetAttributeViBooleanResponse.SerializeToString,
            ),
            'GetAttributeViSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViSession,
                    request_deserializer=nifgen__pb2.GetAttributeViSessionRequest.FromString,
                    response_serializer=nifgen__pb2.GetAttributeViSessionResponse.SerializeToString,
            ),
            'ResetAttribute': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetAttribute,
                    request_deserializer=nifgen__pb2.ResetAttributeRequest.FromString,
                    response_serializer=nifgen__pb2.ResetAttributeResponse.SerializeToString,
            ),
            'ManualEnableP2PStream': grpc.unary_unary_rpc_method_handler(
                    servicer.ManualEnableP2PStream,
                    request_deserializer=nifgen__pb2.ManualEnableP2PStreamRequest.FromString,
                    response_serializer=nifgen__pb2.ManualEnableP2PStreamResponse.SerializeToString,
            ),
            'CreateWaveformFromFileHWS': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWaveformFromFileHWS,
                    request_deserializer=nifgen__pb2.CreateWaveformFromFileHWSRequest.FromString,
                    response_serializer=nifgen__pb2.CreateWaveformFromFileHWSResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nifgen_grpc.NiFgen', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NiFgen(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Init(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/Init',
            nifgen__pb2.InitRequest.SerializeToString,
            nifgen__pb2.InitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitWithOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/InitWithOptions',
            nifgen__pb2.InitWithOptionsRequest.SerializeToString,
            nifgen__pb2.InitWithOptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitializeWithChannels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/InitializeWithChannels',
            nifgen__pb2.InitializeWithChannelsRequest.SerializeToString,
            nifgen__pb2.InitializeWithChannelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Close(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/Close',
            nifgen__pb2.CloseRequest.SerializeToString,
            nifgen__pb2.CloseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/Reset',
            nifgen__pb2.ResetRequest.SerializeToString,
            nifgen__pb2.ResetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SelfTest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SelfTest',
            nifgen__pb2.SelfTestRequest.SerializeToString,
            nifgen__pb2.SelfTestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ErrorQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ErrorQuery',
            nifgen__pb2.ErrorQueryRequest.SerializeToString,
            nifgen__pb2.ErrorQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ErrorMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ErrorMessage',
            nifgen__pb2.ErrorMessageRequest.SerializeToString,
            nifgen__pb2.ErrorMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevisionQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/RevisionQuery',
            nifgen__pb2.RevisionQueryRequest.SerializeToString,
            nifgen__pb2.RevisionQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetError(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetError',
            nifgen__pb2.GetErrorRequest.SerializeToString,
            nifgen__pb2.GetErrorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearError(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ClearError',
            nifgen__pb2.ClearErrorRequest.SerializeToString,
            nifgen__pb2.ClearErrorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ErrorHandler(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ErrorHandler',
            nifgen__pb2.ErrorHandlerRequest.SerializeToString,
            nifgen__pb2.ErrorHandlerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChannelName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetChannelName',
            nifgen__pb2.GetChannelNameRequest.SerializeToString,
            nifgen__pb2.GetChannelNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetInterchangeCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ResetInterchangeCheck',
            nifgen__pb2.ResetInterchangeCheckRequest.SerializeToString,
            nifgen__pb2.ResetInterchangeCheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearInterchangeWarnings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ClearInterchangeWarnings',
            nifgen__pb2.ClearInterchangeWarningsRequest.SerializeToString,
            nifgen__pb2.ClearInterchangeWarningsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InvalidateAllAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/InvalidateAllAttributes',
            nifgen__pb2.InvalidateAllAttributesRequest.SerializeToString,
            nifgen__pb2.InvalidateAllAttributesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetWithDefaults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ResetWithDefaults',
            nifgen__pb2.ResetWithDefaultsRequest.SerializeToString,
            nifgen__pb2.ResetWithDefaultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/Disable',
            nifgen__pb2.DisableRequest.SerializeToString,
            nifgen__pb2.DisableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Commit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/Commit',
            nifgen__pb2.CommitRequest.SerializeToString,
            nifgen__pb2.CommitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHardwareState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetHardwareState',
            nifgen__pb2.GetHardwareStateRequest.SerializeToString,
            nifgen__pb2.GetHardwareStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WaitUntilDone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WaitUntilDone',
            nifgen__pb2.WaitUntilDoneRequest.SerializeToString,
            nifgen__pb2.WaitUntilDoneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsDone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/IsDone',
            nifgen__pb2.IsDoneRequest.SerializeToString,
            nifgen__pb2.IsDoneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ResetDevice',
            nifgen__pb2.ResetDeviceRequest.SerializeToString,
            nifgen__pb2.ResetDeviceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureOperationMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureOperationMode',
            nifgen__pb2.ConfigureOperationModeRequest.SerializeToString,
            nifgen__pb2.ConfigureOperationModeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureOutputMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureOutputMode',
            nifgen__pb2.ConfigureOutputModeRequest.SerializeToString,
            nifgen__pb2.ConfigureOutputModeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureReferenceClock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureReferenceClock',
            nifgen__pb2.ConfigureReferenceClockRequest.SerializeToString,
            nifgen__pb2.ConfigureReferenceClockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureOutputImpedance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureOutputImpedance',
            nifgen__pb2.ConfigureOutputImpedanceRequest.SerializeToString,
            nifgen__pb2.ConfigureOutputImpedanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureOutputEnabled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureOutputEnabled',
            nifgen__pb2.ConfigureOutputEnabledRequest.SerializeToString,
            nifgen__pb2.ConfigureOutputEnabledResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureChannels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureChannels',
            nifgen__pb2.ConfigureChannelsRequest.SerializeToString,
            nifgen__pb2.ConfigureChannelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitiateGeneration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/InitiateGeneration',
            nifgen__pb2.InitiateGenerationRequest.SerializeToString,
            nifgen__pb2.InitiateGenerationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortGeneration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/AbortGeneration',
            nifgen__pb2.AbortGenerationRequest.SerializeToString,
            nifgen__pb2.AbortGenerationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureStandardWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureStandardWaveform',
            nifgen__pb2.ConfigureStandardWaveformRequest.SerializeToString,
            nifgen__pb2.ConfigureStandardWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DefineUserStandardWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/DefineUserStandardWaveform',
            nifgen__pb2.DefineUserStandardWaveformRequest.SerializeToString,
            nifgen__pb2.DefineUserStandardWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearUserStandardWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ClearUserStandardWaveform',
            nifgen__pb2.ClearUserStandardWaveformRequest.SerializeToString,
            nifgen__pb2.ClearUserStandardWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureFrequency(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureFrequency',
            nifgen__pb2.ConfigureFrequencyRequest.SerializeToString,
            nifgen__pb2.ConfigureFrequencyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureAmplitude(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureAmplitude',
            nifgen__pb2.ConfigureAmplitudeRequest.SerializeToString,
            nifgen__pb2.ConfigureAmplitudeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryArbWfmCapabilities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/QueryArbWfmCapabilities',
            nifgen__pb2.QueryArbWfmCapabilitiesRequest.SerializeToString,
            nifgen__pb2.QueryArbWfmCapabilitiesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWaveformF64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateWaveformF64',
            nifgen__pb2.CreateWaveformF64Request.SerializeToString,
            nifgen__pb2.CreateWaveformF64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWaveformI16(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateWaveformI16',
            nifgen__pb2.CreateWaveformI16Request.SerializeToString,
            nifgen__pb2.CreateWaveformI16Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWaveformComplexF64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateWaveformComplexF64',
            nifgen__pb2.CreateWaveformComplexF64Request.SerializeToString,
            nifgen__pb2.CreateWaveformComplexF64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWaveformFromFileI16(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateWaveformFromFileI16',
            nifgen__pb2.CreateWaveformFromFileI16Request.SerializeToString,
            nifgen__pb2.CreateWaveformFromFileI16Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWaveformFromFileF64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateWaveformFromFileF64',
            nifgen__pb2.CreateWaveformFromFileF64Request.SerializeToString,
            nifgen__pb2.CreateWaveformFromFileF64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureSampleRate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureSampleRate',
            nifgen__pb2.ConfigureSampleRateRequest.SerializeToString,
            nifgen__pb2.ConfigureSampleRateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureArbWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureArbWaveform',
            nifgen__pb2.ConfigureArbWaveformRequest.SerializeToString,
            nifgen__pb2.ConfigureArbWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearArbWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ClearArbWaveform',
            nifgen__pb2.ClearArbWaveformRequest.SerializeToString,
            nifgen__pb2.ClearArbWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AllocateNamedWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/AllocateNamedWaveform',
            nifgen__pb2.AllocateNamedWaveformRequest.SerializeToString,
            nifgen__pb2.AllocateNamedWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetNamedWaveformNextWritePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SetNamedWaveformNextWritePosition',
            nifgen__pb2.SetNamedWaveformNextWritePositionRequest.SerializeToString,
            nifgen__pb2.SetNamedWaveformNextWritePositionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteNamedWaveformF64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteNamedWaveformF64',
            nifgen__pb2.WriteNamedWaveformF64Request.SerializeToString,
            nifgen__pb2.WriteNamedWaveformF64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteNamedWaveformI16(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteNamedWaveformI16',
            nifgen__pb2.WriteNamedWaveformI16Request.SerializeToString,
            nifgen__pb2.WriteNamedWaveformI16Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteNamedWaveformComplexF64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteNamedWaveformComplexF64',
            nifgen__pb2.WriteNamedWaveformComplexF64Request.SerializeToString,
            nifgen__pb2.WriteNamedWaveformComplexF64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteNamedWaveformComplexI16(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteNamedWaveformComplexI16',
            nifgen__pb2.WriteNamedWaveformComplexI16Request.SerializeToString,
            nifgen__pb2.WriteNamedWaveformComplexI16Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNamedWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/DeleteNamedWaveform',
            nifgen__pb2.DeleteNamedWaveformRequest.SerializeToString,
            nifgen__pb2.DeleteNamedWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryArbSeqCapabilities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/QueryArbSeqCapabilities',
            nifgen__pb2.QueryArbSeqCapabilitiesRequest.SerializeToString,
            nifgen__pb2.QueryArbSeqCapabilitiesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateArbSequence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateArbSequence',
            nifgen__pb2.CreateArbSequenceRequest.SerializeToString,
            nifgen__pb2.CreateArbSequenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAdvancedArbSequence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateAdvancedArbSequence',
            nifgen__pb2.CreateAdvancedArbSequenceRequest.SerializeToString,
            nifgen__pb2.CreateAdvancedArbSequenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureArbSequence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureArbSequence',
            nifgen__pb2.ConfigureArbSequenceRequest.SerializeToString,
            nifgen__pb2.ConfigureArbSequenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearArbSequence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ClearArbSequence',
            nifgen__pb2.ClearArbSequenceRequest.SerializeToString,
            nifgen__pb2.ClearArbSequenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearArbMemory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ClearArbMemory',
            nifgen__pb2.ClearArbMemoryRequest.SerializeToString,
            nifgen__pb2.ClearArbMemoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryFreqListCapabilities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/QueryFreqListCapabilities',
            nifgen__pb2.QueryFreqListCapabilitiesRequest.SerializeToString,
            nifgen__pb2.QueryFreqListCapabilitiesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFreqList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateFreqList',
            nifgen__pb2.CreateFreqListRequest.SerializeToString,
            nifgen__pb2.CreateFreqListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureFreqList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureFreqList',
            nifgen__pb2.ConfigureFreqListRequest.SerializeToString,
            nifgen__pb2.ConfigureFreqListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearFreqList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ClearFreqList',
            nifgen__pb2.ClearFreqListRequest.SerializeToString,
            nifgen__pb2.ClearFreqListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteScript(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteScript',
            nifgen__pb2.WriteScriptRequest.SerializeToString,
            nifgen__pb2.WriteScriptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteScript(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/DeleteScript',
            nifgen__pb2.DeleteScriptRequest.SerializeToString,
            nifgen__pb2.DeleteScriptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExportSignal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ExportSignal',
            nifgen__pb2.ExportSignalRequest.SerializeToString,
            nifgen__pb2.ExportSignalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RouteSignalOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/RouteSignalOut',
            nifgen__pb2.RouteSignalOutRequest.SerializeToString,
            nifgen__pb2.RouteSignalOutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendSoftwareEdgeTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SendSoftwareEdgeTrigger',
            nifgen__pb2.SendSoftwareEdgeTriggerRequest.SerializeToString,
            nifgen__pb2.SendSoftwareEdgeTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureDigitalEdgeStartTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureDigitalEdgeStartTrigger',
            nifgen__pb2.ConfigureDigitalEdgeStartTriggerRequest.SerializeToString,
            nifgen__pb2.ConfigureDigitalEdgeStartTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureSoftwareEdgeStartTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureSoftwareEdgeStartTrigger',
            nifgen__pb2.ConfigureSoftwareEdgeStartTriggerRequest.SerializeToString,
            nifgen__pb2.ConfigureSoftwareEdgeStartTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableStartTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/DisableStartTrigger',
            nifgen__pb2.DisableStartTriggerRequest.SerializeToString,
            nifgen__pb2.DisableStartTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureP2PEndpointFullnessStartTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureP2PEndpointFullnessStartTrigger',
            nifgen__pb2.ConfigureP2PEndpointFullnessStartTriggerRequest.SerializeToString,
            nifgen__pb2.ConfigureP2PEndpointFullnessStartTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureDigitalEdgeScriptTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureDigitalEdgeScriptTrigger',
            nifgen__pb2.ConfigureDigitalEdgeScriptTriggerRequest.SerializeToString,
            nifgen__pb2.ConfigureDigitalEdgeScriptTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureDigitalLevelScriptTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureDigitalLevelScriptTrigger',
            nifgen__pb2.ConfigureDigitalLevelScriptTriggerRequest.SerializeToString,
            nifgen__pb2.ConfigureDigitalLevelScriptTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureSoftwareEdgeScriptTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureSoftwareEdgeScriptTrigger',
            nifgen__pb2.ConfigureSoftwareEdgeScriptTriggerRequest.SerializeToString,
            nifgen__pb2.ConfigureSoftwareEdgeScriptTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableScriptTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/DisableScriptTrigger',
            nifgen__pb2.DisableScriptTriggerRequest.SerializeToString,
            nifgen__pb2.DisableScriptTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureClockMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureClockMode',
            nifgen__pb2.ConfigureClockModeRequest.SerializeToString,
            nifgen__pb2.ConfigureClockModeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdjustSampleClockRelativeDelay(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/AdjustSampleClockRelativeDelay',
            nifgen__pb2.AdjustSampleClockRelativeDelayRequest.SerializeToString,
            nifgen__pb2.AdjustSampleClockRelativeDelayResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AllocateWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/AllocateWaveform',
            nifgen__pb2.AllocateWaveformRequest.SerializeToString,
            nifgen__pb2.AllocateWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetWaveformNextWritePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SetWaveformNextWritePosition',
            nifgen__pb2.SetWaveformNextWritePositionRequest.SerializeToString,
            nifgen__pb2.SetWaveformNextWritePositionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteWaveform',
            nifgen__pb2.WriteWaveformRequest.SerializeToString,
            nifgen__pb2.WriteWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteBinary16Waveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteBinary16Waveform',
            nifgen__pb2.WriteBinary16WaveformRequest.SerializeToString,
            nifgen__pb2.WriteBinary16WaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteWaveformComplexF64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteWaveformComplexF64',
            nifgen__pb2.WriteWaveformComplexF64Request.SerializeToString,
            nifgen__pb2.WriteWaveformComplexF64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteComplexBinary16Waveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteComplexBinary16Waveform',
            nifgen__pb2.WriteComplexBinary16WaveformRequest.SerializeToString,
            nifgen__pb2.WriteComplexBinary16WaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SelfCal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SelfCal',
            nifgen__pb2.SelfCalRequest.SerializeToString,
            nifgen__pb2.SelfCalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSelfCalSupported(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetSelfCalSupported',
            nifgen__pb2.GetSelfCalSupportedRequest.SerializeToString,
            nifgen__pb2.GetSelfCalSupportedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSelfCalLastDateAndTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetSelfCalLastDateAndTime',
            nifgen__pb2.GetSelfCalLastDateAndTimeRequest.SerializeToString,
            nifgen__pb2.GetSelfCalLastDateAndTimeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtCalLastDateAndTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetExtCalLastDateAndTime',
            nifgen__pb2.GetExtCalLastDateAndTimeRequest.SerializeToString,
            nifgen__pb2.GetExtCalLastDateAndTimeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSelfCalLastTemp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetSelfCalLastTemp',
            nifgen__pb2.GetSelfCalLastTempRequest.SerializeToString,
            nifgen__pb2.GetSelfCalLastTempResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtCalLastTemp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetExtCalLastTemp',
            nifgen__pb2.GetExtCalLastTempRequest.SerializeToString,
            nifgen__pb2.GetExtCalLastTempResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtCalRecommendedInterval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetExtCalRecommendedInterval',
            nifgen__pb2.GetExtCalRecommendedIntervalRequest.SerializeToString,
            nifgen__pb2.GetExtCalRecommendedIntervalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadCurrentTemperature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ReadCurrentTemperature',
            nifgen__pb2.ReadCurrentTemperatureRequest.SerializeToString,
            nifgen__pb2.ReadCurrentTemperatureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureCustomFIRFilterCoefficients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureCustomFIRFilterCoefficients',
            nifgen__pb2.ConfigureCustomFIRFilterCoefficientsRequest.SerializeToString,
            nifgen__pb2.ConfigureCustomFIRFilterCoefficientsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFIRFilterCoefficients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetFIRFilterCoefficients',
            nifgen__pb2.GetFIRFilterCoefficientsRequest.SerializeToString,
            nifgen__pb2.GetFIRFilterCoefficientsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStreamEndpointHandle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetStreamEndpointHandle',
            nifgen__pb2.GetStreamEndpointHandleRequest.SerializeToString,
            nifgen__pb2.GetStreamEndpointHandleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteP2PEndpointI16(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/WriteP2PEndpointI16',
            nifgen__pb2.WriteP2PEndpointI16Request.SerializeToString,
            nifgen__pb2.WriteP2PEndpointI16Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureSynchronization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureSynchronization',
            nifgen__pb2.ConfigureSynchronizationRequest.SerializeToString,
            nifgen__pb2.ConfigureSynchronizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableDigitalPatterning(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/EnableDigitalPatterning',
            nifgen__pb2.EnableDigitalPatterningRequest.SerializeToString,
            nifgen__pb2.EnableDigitalPatterningResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableDigitalPatterning(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/DisableDigitalPatterning',
            nifgen__pb2.DisableDigitalPatterningRequest.SerializeToString,
            nifgen__pb2.DisableDigitalPatterningResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableDigitalFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/EnableDigitalFilter',
            nifgen__pb2.EnableDigitalFilterRequest.SerializeToString,
            nifgen__pb2.EnableDigitalFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableDigitalFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/DisableDigitalFilter',
            nifgen__pb2.DisableDigitalFilterRequest.SerializeToString,
            nifgen__pb2.DisableDigitalFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableAnalogFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/EnableAnalogFilter',
            nifgen__pb2.EnableAnalogFilterRequest.SerializeToString,
            nifgen__pb2.EnableAnalogFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableAnalogFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/DisableAnalogFilter',
            nifgen__pb2.DisableAnalogFilterRequest.SerializeToString,
            nifgen__pb2.DisableAnalogFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureSampleClockSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureSampleClockSource',
            nifgen__pb2.ConfigureSampleClockSourceRequest.SerializeToString,
            nifgen__pb2.ConfigureSampleClockSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureTriggerMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ConfigureTriggerMode',
            nifgen__pb2.ConfigureTriggerModeRequest.SerializeToString,
            nifgen__pb2.ConfigureTriggerModeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ImportAttributeConfigurationFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ImportAttributeConfigurationFile',
            nifgen__pb2.ImportAttributeConfigurationFileRequest.SerializeToString,
            nifgen__pb2.ImportAttributeConfigurationFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExportAttributeConfigurationFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ExportAttributeConfigurationFile',
            nifgen__pb2.ExportAttributeConfigurationFileRequest.SerializeToString,
            nifgen__pb2.ExportAttributeConfigurationFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ImportAttributeConfigurationBuffer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ImportAttributeConfigurationBuffer',
            nifgen__pb2.ImportAttributeConfigurationBufferRequest.SerializeToString,
            nifgen__pb2.ImportAttributeConfigurationBufferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExportAttributeConfigurationBuffer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ExportAttributeConfigurationBuffer',
            nifgen__pb2.ExportAttributeConfigurationBufferRequest.SerializeToString,
            nifgen__pb2.ExportAttributeConfigurationBufferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViInt64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SetAttributeViInt64',
            nifgen__pb2.SetAttributeViInt64Request.SerializeToString,
            nifgen__pb2.SetAttributeViInt64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViInt64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CheckAttributeViInt64',
            nifgen__pb2.CheckAttributeViInt64Request.SerializeToString,
            nifgen__pb2.CheckAttributeViInt64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViInt64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetAttributeViInt64',
            nifgen__pb2.GetAttributeViInt64Request.SerializeToString,
            nifgen__pb2.GetAttributeViInt64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViInt32(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SetAttributeViInt32',
            nifgen__pb2.SetAttributeViInt32Request.SerializeToString,
            nifgen__pb2.SetAttributeViInt32Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViReal64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SetAttributeViReal64',
            nifgen__pb2.SetAttributeViReal64Request.SerializeToString,
            nifgen__pb2.SetAttributeViReal64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SetAttributeViString',
            nifgen__pb2.SetAttributeViStringRequest.SerializeToString,
            nifgen__pb2.SetAttributeViStringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViBoolean(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SetAttributeViBoolean',
            nifgen__pb2.SetAttributeViBooleanRequest.SerializeToString,
            nifgen__pb2.SetAttributeViBooleanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/SetAttributeViSession',
            nifgen__pb2.SetAttributeViSessionRequest.SerializeToString,
            nifgen__pb2.SetAttributeViSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViInt32(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CheckAttributeViInt32',
            nifgen__pb2.CheckAttributeViInt32Request.SerializeToString,
            nifgen__pb2.CheckAttributeViInt32Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViReal64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CheckAttributeViReal64',
            nifgen__pb2.CheckAttributeViReal64Request.SerializeToString,
            nifgen__pb2.CheckAttributeViReal64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CheckAttributeViString',
            nifgen__pb2.CheckAttributeViStringRequest.SerializeToString,
            nifgen__pb2.CheckAttributeViStringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViBoolean(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CheckAttributeViBoolean',
            nifgen__pb2.CheckAttributeViBooleanRequest.SerializeToString,
            nifgen__pb2.CheckAttributeViBooleanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CheckAttributeViSession',
            nifgen__pb2.CheckAttributeViSessionRequest.SerializeToString,
            nifgen__pb2.CheckAttributeViSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViInt32(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetAttributeViInt32',
            nifgen__pb2.GetAttributeViInt32Request.SerializeToString,
            nifgen__pb2.GetAttributeViInt32Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViReal64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetAttributeViReal64',
            nifgen__pb2.GetAttributeViReal64Request.SerializeToString,
            nifgen__pb2.GetAttributeViReal64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetAttributeViString',
            nifgen__pb2.GetAttributeViStringRequest.SerializeToString,
            nifgen__pb2.GetAttributeViStringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViBoolean(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetAttributeViBoolean',
            nifgen__pb2.GetAttributeViBooleanRequest.SerializeToString,
            nifgen__pb2.GetAttributeViBooleanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/GetAttributeViSession',
            nifgen__pb2.GetAttributeViSessionRequest.SerializeToString,
            nifgen__pb2.GetAttributeViSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetAttribute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ResetAttribute',
            nifgen__pb2.ResetAttributeRequest.SerializeToString,
            nifgen__pb2.ResetAttributeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ManualEnableP2PStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/ManualEnableP2PStream',
            nifgen__pb2.ManualEnableP2PStreamRequest.SerializeToString,
            nifgen__pb2.ManualEnableP2PStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWaveformFromFileHWS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nifgen_grpc.NiFgen/CreateWaveformFromFileHWS',
            nifgen__pb2.CreateWaveformFromFileHWSRequest.SerializeToString,
            nifgen__pb2.CreateWaveformFromFileHWSResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
